@@ -6,14 +6,17 @@ sentry.queue.worker
 :license: BSD, see LICENSE for more details.
 """
 from kombu.mixins import ConsumerMixin
-from kombu.utils import kwdict, reprcall
+from kombu.utils import kwdict
 
 from sentry.queue.queues import task_queues
 
+import logging
+
 
 class Worker(ConsumerMixin):
     def __init__(self, connection):
         self.connection = connection
+        self.logger = logging.getLogger(__name__)
 
     def get_consumers(self, Consumer, channel):
         return [Consumer(queues=task_queues,
@@ -23,10 +26,10 @@ class Worker(ConsumerMixin):
         func = body["func"]
         args = body["args"]
         kwargs = body["kwargs"]
-        self.info("Got task: %s", reprcall(func.__name__, args, kwargs))
+        self.logger.info("Got task: %r", func.__name__)
         try:
             func(*args, **kwdict(kwargs))
         except Exception, exc:
-            self.error("task raised exception: %r", exc)
+            self.logger.error("task raised exception: %r", exc)
         message.ack()
 
